Luna Soleil Tarot Deck – Terra Soleil
Description: Spellbound stars and moonlight align with our #1 bestselling Luna Soleil Tarot Deck ™ This is a complete deck of 78 cards in the traditional tarot format, with numbered cards and suits for the major and minor arcana. This magical deck was designed for anyone to use, from beginners to advanced tarot readers. These cards

Skip to content

FREE U.S. SHIPPING | EXTRA 10% OFF ORDERS $50+ | ENDS NOVEMBER 30

# Luna Soleil Tarot Deck

Brand
  Terra Soleil
Regular price
  $69.99
Sale price
  $69.99

Quantity must be 1 or more
Card Color
Quantity
This item is a recurring or deferred purchase. By continuing, I agree to the cancellation policy and authorize you to charge my payment method at the prices, frequency and dates listed on this page until my order is fulfilled or I cancel, if permitted.

Spellbound stars and moonlight align with our #1 bestselling Luna Soleil Tarot Deck ™ This is a complete deck of 78 cards in the traditional tarot format, with numbered cards and suits for the major and minor arcana. This magical deck was designed for anyone to use, from beginners to advanced tarot readers.

These cards are intricately designed, featuring celestial art designed by Annalise Dragonetti, the founder and creative director of Terra Soleil. The back of each tarot card has a mesmerizing zodiac constellation, with printed flecks of gold shimmer woven through the stars.

Please read the information below carefully before purchasing.

What's Included?

- Complete Tarot Deck | 78 Cards | Includes the Major and Minor Arcana
- Linen Ritual Pouch | Eco-friendly and Reusable
- Hand-Selected Quartz Healing Crystal
- Gold-Foil Moon + Stars Crystal Pouch
- Optional 168 Page Guidebook (sold separately here.)

Choose Your Deck Color

I. Onyx | Black Cards with Gold Artwork + Gold-Gilded Edges
II. Quartz | White Cards with Gold Artwork + Gold-Gilded Edges
III. Sand | Soft Camel Cards with Gold Artwork + Gold-Gilded Edges
IV. Rose Quartz | Blush Pink Cards with Gold Artwork + Gold-Gilded Edges
Details + Dimensions

- Measures 2.75" x 4.75"
- Premium 300GSM Cardstock
- Smooth Satin Finish Front + Back (not foiled)
- Rounded, Gold-Gilded Edges

Terra Soleil ™ holds copyright on all designs and the products that incorporate those designs. We hold copyright of the description of our listings, the product names, and the product titles. Do not attempt to copy and paste our descriptions or products as your own. It is obvious, and we will not hesitate to take action against your brand, company, or shop. The designs, products, and/or branding of our items are not to be reproduced under any circumstances. Any infringement on our copyright will be met with legal action.
Copyright © Terra Soleil

- Product Information

Spellbound stars and moonlight align with our #1 bestselling Luna Soleil Tarot Deck ™ This is a complete deck of 78 cards in the traditional tarot format, with numbered cards and suits for the major and minor arcana. This magical deck was designed for anyone to use, from beginners to advanced tarot readers.

These cards are intricately designed, featuring celestial art designed by Annalise Dragonetti, the founder and creative director of Terra Soleil. The back of each tarot card has a mesmerizing zodiac constellation, with printed flecks of gold shimmer woven through the stars.

Please read the information below carefully before purchasing.

What's Included?

- Complete Tarot Deck | 78 Cards | Includes the Major and Minor Arcana
- Linen Ritual Pouch | Eco-friendly and Reusable
- Hand-Selected Quartz Healing Crystal
- Gold-Foil Moon + Stars Crystal Pouch
- Optional 168 Page Guidebook (sold separately here.)

Choose Your Deck Color

I. Onyx | Black Cards with Gold Artwork + Gold-Gilded Edges
II. Quartz | White Cards with Gold Artwork + Gold-Gilded Edges
III. Sand | Soft Camel Cards with Gold Artwork + Gold-Gilded Edges
IV. Rose Quartz | Blush Pink Cards with Gold Artwork + Gold-Gilded Edges
Details + Dimensions

- Measures 2.75" x 4.75"
- Premium 300GSM Cardstock
- Smooth Satin Finish Front + Back (not foiled)
- Rounded, Gold-Gilded Edges

Terra Soleil ™ holds copyright on all designs and the products that incorporate those designs. We hold copyright of the description of our listings, the product names, and the product titles. Do not attempt to copy and paste our descriptions or products as your own. It is obvious, and we will not hesitate to take action against your brand, company, or shop. The designs, products, and/or branding of our items are not to be reproduced under any circumstances. Any infringement on our copyright will be met with legal action.
Copyright © Terra Soleil

- Frequently Asked Questions

Q. Does this deck come with a complete guidebook?
A. The matching guidebook is sold separately. You can purchase the guidebook here.
Q. Are the front and back of the decks gold-gilded (foiled), or only the edges?
A. Only the edges of our Luna Soleil decks have reflective gilding. For all our decks, the front and back of the cards are printed with a smooth, satin finish and are not foiled/reflective. The gold printing is part of the digital design of the artwork, so the surface of the deck is not reflective.
Q. I noticed that gold glitter seems to be falling off the edges of the cards. Is this normal?
A. Yes, this is a completely normal and unavoidable part of paper printing (think of it as stardust!) Particles of gold-gilt may rub off the edge of the cards after the extremely delicate gilding process. It does not indicate that your cards are faulty in any way. It simply means that your deck is freshly gilded. The gold gilded edges will settle within a few days of opening the cards. Any gold gilt that falls off is simply extraneous and did not adhere to the edges in the first place (since there was already gold gilt in those spots that had adhered to the deck.) Our decks are printed in small batches of less than 1000 units at a time, meaning they are always carefully inspected for quality control after the gilding process has been completed.
Q. Are the cards in the traditional Rider Waite Tarot format?
A. Yes, all our tarot decks follow the classic tarot structure. This means that there are 22 major arcana cards (e.g. The Devil, The Empress, etc.) and 56 minor arcana cards (Suit of Wands, Suit of Cups, Suit of Swords, and Suit of Pentacles.)
Q. Do you offer wholesale pricing?
A. Yes, we offer wholesale pricing on all of our card decks. For more information, please message us at info@terrasoleil.com Please include your business name, your country, the products you're interested in, and an approximate number of how many units you'd like to purchase.

Product Change Notices
May 22, 2021 • All orders for the ROSE QUARTZ DECK placed after this date will feature gold-gilt edges.
July 22, 2021 • All orders for the ONYX DECK placed after this date will feature gold-gilt edges.
August 14, 2021 • All orders for the SAND DECK placed after this date will feature gold-gilt edges.

July 30, 2023 • All orders for the QUARTZ DECK placed after this date will feature gold-gilt edges.

Back to Bestsellers

# shop our instagram

@terrasoleil

Modern Aphrodite Tarot Deck
Modern Aphrodite Tarot Deck

Regular price
  $69.99
Sale price
  $69.99

Cosmic Goddess Oracle Deck
Cosmic Goddess Oracle Deck

Regular price
  $59.99
Sale price
  $59.99

Stardust Tarot Deck
Stardust Tarot Deck

Regular price
  $69.99
Sale price
  $69.99

Dreamspell Tarot Deck
Dreamspell Tarot Deck

Regular price
  $69.99
Sale price
  $69.99

Luna Soleil Tarot Deck
Luna Soleil Tarot Deck

Regular price
  $69.99
Sale price
  $69.99

Luna Soleil Tarot Deck
Luna Soleil Tarot Deck

Regular price
  $69.99
Sale price
  $69.99

Luna Soleil Tarot Deck
Luna Soleil Tarot Deck

Regular price
  $69.99
Sale price
  $69.99

Moondust Tarot Deck
Moondust Tarot Deck

Regular price
  $69.99
Sale price
  $69.99

Venus & Calypso Oracle Deck
Venus & Calypso Oracle Deck

Regular price
  SOLD OUT
Sale price
  $39.99

Stardust Tarot Guidebook
Stardust Tarot Guidebook

Regular price
  $39.99
Sale price
  $29.99

Use left/right arrows to navigate the slideshow or swipe left/right if using a mobile device

- choosing a selection results in a full page refresh

#### WHAT'S YOUR EMAIL?

Product has been added to your wishlist.
You can view your wishlist by creating or login account.
Please create account through ##customer_email## email
Login Register